summaryrefslogtreecommitdiff
path: root/src/gui/windows/updaterwindow.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/windows/updaterwindow.h')
-rw-r--r--src/gui/windows/updaterwindow.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/gui/windows/updaterwindow.h b/src/gui/windows/updaterwindow.h
index ba836a658..a1b693408 100644
--- a/src/gui/windows/updaterwindow.h
+++ b/src/gui/windows/updaterwindow.h
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -130,9 +130,9 @@ class UpdaterWindow final : public Window,
const std::string &restrict fixPath,
const std::string &filerestrict);
- static void loadManaPlusUpdates(const std::string &dir);
+ static void loadManaVerseUpdates(const std::string &dir);
- static void unloadManaPlusUpdates(const std::string &dir);
+ static void unloadManaVerseUpdates(const std::string &dir);
static unsigned long getFileHash(const std::string &filePath);
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify